Exception: SmsRu::Error
- Inherits:
-
StandardError
- Object
- StandardError
- SmsRu::Error
- Defined in:
- lib/sms_ru/errors.rb
Overview
Base class for every error raised by the gem. Rescue this to catch them all.
Base class for every error raised by the gem. Rescue this to catch them all.